@@ -26,12 +26,15 @@ int
 mpfr_set_si_2exp (mpfr_ptr x, long i, mp_exp_t e, mp_rnd_t rnd_mode)
 {
   int res;
-  MPFR_SAVE_EXPO_DECL (expo);
 
-  MPFR_SAVE_EXPO_MARK (expo);
+  mpfr_save_emin_emax ();
   res = mpfr_set_si (x, i, rnd_mode);
-  mpfr_mul_2si (x, x, e, rnd_mode); /* Should be exact */
-  MPFR_SAVE_EXPO_FREE (expo);
-  res = mpfr_check_range(x, res, rnd_mode);
+  MPFR_ASSERTD ( res == 0);
+  MPFR_ASSERTD (e == (mp_exp_t)(long) e);
+  res = mpfr_mul_2si (x, x, e, rnd_mode);
+  mpfr_restore_emin_emax ();
+  if (res)
+    return res;
+  res = mpfr_check_range(x, 0, rnd_mode);
   return res;
 }
