@@ -133,6 +133,7 @@ gel_matrixw_new(void)
 	m->cached_value_only_real = 0;
 	m->cached_value_only_rational = 0;
 	m->cached_value_only_integer = 0;
+	m->cached_value_or_bool_only = 0;
 	
 	m->tr = 0;
 	m->regx = NULL;
@@ -162,6 +163,7 @@ gel_matrixw_new_with_matrix(GelMatrix *mat)
 	m->cached_value_only_real = 0;
 	m->cached_value_only_rational = 0;
 	m->cached_value_only_integer = 0;
+	m->cached_value_or_bool_only = 0;
 	
 	m->tr = 0;
 	m->regx = NULL;
@@ -423,8 +425,8 @@ gel_matrixw_set_size (GelMatrixW *m, int nwidth, int nheight)
 		m->regw = width;
 		m->regh = height;
 	} else if (m->m->use > 1) {
-		/* since the use is greater then 1, we WILL get a copy of this matrix at
-		 * the right size */
+		/* since the use is greater than 1, we WILL get a copy of
+		 * this matrix at the right size */
 		internal_make_private (m, width, height);
 		g_assert (m->m->use == 1);
 	} else /* m->m->use == 1 */{
@@ -890,6 +892,7 @@ internal_make_private (GelMatrixW *m, int w, int h)
 	m->cached_value_only_real = 0;
 	m->cached_value_only_rational = 0;
 	m->cached_value_only_integer = 0;
+	m->cached_value_or_bool_only = 0;
 
 #ifdef MATRIX_DEBUG
 	printf ("Make private %p %d %d\n", m, w, h);
